ReadStatCliCommands

Enum ReadStatCliCommands 

pub enum ReadStatCliCommands {
    Metadata {
        input: PathBuf,
        as_json: bool,
        no_progress: bool,
        skip_row_count: bool,
    },
    Preview {
        input: PathBuf,
        rows: u32,
        reader: Option<Reader>,
        stream_rows: Option<u32>,
        no_progress: bool,
        columns: Option<Vec<String>>,
        columns_file: Option<PathBuf>,
    },
    Data {
Show 15 fields input: PathBuf, output: Option<PathBuf>, format: Option<CliOutFormat>, overwrite: bool, rows: Option<u32>, reader: Option<Reader>, stream_rows: Option<u32>, no_progress: bool, parallel: bool, parallel_write: bool, parallel_write_buffer_mb: u64, compression: Option<CliParquetCompression>, compression_level: Option<u32>, columns: Option<Vec<String>>, columns_file: Option<PathBuf>,
}, }
CLI subcommands for readstat.

Variants



Metadata

Display sas7bdat metadata

Fields

input: PathBuf

Path to sas7bdat file

as_json: bool

Display sas7bdat metadata as json

no_progress: bool

Do not display progress bar

skip_row_count: bool

Skip calculating row count{n}If only interested in variable metadata speeds up parsing



Preview

Preview sas7bdat data

Fields

input: PathBuf

Path to sas7bdat file

rows: u32

Number of rows to write

reader: Option<Reader>

Type of reader{n} mem = read all data into memory{n} stream = read at most stream-rows into memory{n}Defaults to stream

stream_rows: Option<u32>

Number of rows to stream (read into memory) at a time{n}↑ rows = ↑ memory usage{n}Ignored if reader is set to mem{n}Defaults to 10,000 rows

no_progress: bool

Do not display progress bar

columns: Option<Vec<String>>

Comma-separated list of column names to include in output

columns_file: Option<PathBuf>

Path to a file containing column names (one per line, # comments)



Data

Convert sas7bdat data to csv, feather (or the Arrow IPC format), ndjson, or parquet format

Fields

input: PathBuf

Path to sas7bdat file

output: Option<PathBuf>

Output file path

format: Option<CliOutFormat>

Output file format{n}Defaults to csv

overwrite: bool

Overwrite output file if it already exists

rows: Option<u32>

Number of rows to write

reader: Option<Reader>

Type of reader{n} mem = read all data into memory{n} stream = read at most stream-rows into memory{n}Defaults to stream

stream_rows: Option<u32>

Number of rows to stream (read into memory) at a time{n}↑ rows = ↑ memory usage{n}Ignored if reader is set to mem{n}Defaults to 10,000 rows

no_progress: bool

Do not display progress bar

parallel: bool

Convert sas7bdat data in parallel

parallel_write: bool

Write output data in parallel{n}Only effective when parallel is enabled{n}May write batches out of order for Parquet/Feather

parallel_write_buffer_mb: u64

Memory buffer size in MB before spilling to disk during parallel writes{n}Defaults to 100 MB{n}Only effective when parallel-write is enabled

compression: Option<CliParquetCompression>

Parquet compression algorithm

compression_level: Option<u32>

Parquet compression level (if applicable)

columns: Option<Vec<String>>

Comma-separated list of column names to include in output

columns_file: Option<PathBuf>

Path to a file containing column names (one per line, # comments)