unsafe extern "C" fn buffer_seek(
offset: readstat_off_t,
whence: readstat_io_flags_t,
io_ctx: *mut c_void,
) -> readstat_off_tExpand description
Seek handler that repositions the read cursor within the buffer.
unsafe extern "C" fn buffer_seek(
offset: readstat_off_t,
whence: readstat_io_flags_t,
io_ctx: *mut c_void,
) -> readstat_off_tSeek handler that repositions the read cursor within the buffer.