#[non_exhaustive]pub enum OutFormat {
Csv,
Feather,
Ndjson,
Parquet,
}Expand description
Output file format for data conversion.
All variants are always present regardless of enabled features. Attempting to use a format whose feature is not enabled will result in a compile-time error in the writer code.
This enum is #[non_exhaustive]: new format variants may be added in
minor releases. Match with a wildcard arm to remain forward-compatible.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Csv
Comma-separated values.
Feather
Feather (Arrow IPC) format.
Ndjson
Newline-delimited JSON.
Parquet
Apache Parquet columnar format.