run

Function run 

pub fn run(rs: ReadStatCli) -> Result<(), ReadStatError>
Executes the CLI command specified by the parsed ReadStatCli arguments.

This is the main entry point for the CLI binary, dispatching to the metadata, preview, or data subcommand.