fn run_preview(cmd: ReadStatCliCommands) -> Result<(), ReadStatError>Expand description
Handle the preview subcommand: read a limited number of rows and write to stdout as CSV.
fn run_preview(cmd: ReadStatCliCommands) -> Result<(), ReadStatError>Handle the preview subcommand: read a limited number of rows and write to stdout as CSV.