pub struct ReadStatVarMetadata {
pub var_name: String,
pub var_type: ReadStatVarType,
pub var_type_class: ReadStatVarTypeClass,
pub var_label: String,
pub var_format: String,
pub var_format_class: Option<ReadStatVarFormatClass>,
pub storage_width: usize,
pub display_width: i32,
}Expand description
Metadata for a single variable (column) in a SAS dataset.
Fields
var_name: StringVariable name as defined in the SAS file.
var_type: ReadStatVarTypeStorage type of the variable.
var_type_class: ReadStatVarTypeClassHigh-level type class (string or numeric).
var_label: StringUser-assigned variable label (may be empty).
var_format: StringSAS format string (e.g. "DATE9", "BEST12").
var_format_class: Option<ReadStatVarFormatClass>Semantic format class derived from the format string, if date/time-related.
storage_width: usizeNumber of bytes used to store the variable value. Always 8 for SAS numeric variables; variable for strings.
display_width: i32Display width hint from the file. 0 for sas7bdat; populated for XPORT/SPSS.
Implementations
Sourceimpl ReadStatVarMetadata
impl ReadStatVarMetadata
Sourcepub fn new(
var_name: String,
var_type: ReadStatVarType,
var_type_class: ReadStatVarTypeClass,
var_label: String,
var_format: String,
var_format_class: Option<ReadStatVarFormatClass>,
storage_width: usize,
display_width: i32,
) -> Self
pub fn new( var_name: String, var_type: ReadStatVarType, var_type_class: ReadStatVarTypeClass, var_label: String, var_format: String, var_format_class: Option<ReadStatVarFormatClass>, storage_width: usize, display_width: i32, ) -> Self
Creates a new ReadStatVarMetadata with the given field values.