pub enum OutFormat {
Csv,
Feather,
Ndjson,
Parquet,
}Expand description
Output file format for data conversion.
All variants are always present regardless of enabled features. Attempting to use a format whose feature is not enabled will result in a compile-time error in the writer code.
Variants
Csv
Comma-separated values.
Feather
Feather (Arrow IPC) format.
Ndjson
Newline-delimited JSON.
Parquet
Apache Parquet columnar format.